.. -*- mode: rst -*-

StatsModels Visualizers
=======================

.. automodule:: yellowbrick.contrib.statsmodels.base
    :members: StatsModelsWrapper
    :undoc-members:
    :show-inheritance:
